summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h')
-rw-r--r--kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h b/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
index f570d92..0aebe23 100644
--- a/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
+++ b/kmymoney2/mymoney/storage/mymoneyseqaccessmgr.h
@@ -219,13 +219,13 @@ public:
/**
* This method is used to add one account as sub-ordinate to another
- * (tqparent) account. The objects passed as arguments will be modified
+ * (parent) account. The objects passed as arguments will be modified
* accordingly.
*
* @param tqparent tqparent account the account should be added to
* @param account the account to be added
*/
- void addAccount(MyMoneyAccount& tqparent, MyMoneyAccount& account);
+ void addAccount(MyMoneyAccount& parent, MyMoneyAccount& account);
/**
* Adds an institution to the storage. A
@@ -291,9 +291,9 @@ public:
* An exception will be thrown upon error conditions.
*
* @param account MyMoneyAccount reference to account to be re-parented
* @param tqparent MyMoneyAccount reference to new tqparent account
*/
- void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& tqparent);
+ void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& parent);
/**
* This method is used to remove a transaction from the transaction
@@ -1212,11 +1212,11 @@ private:
* An exception will be thrown upon error conditions.
*
* @param account MyMoneyAccount reference to account to be re-parented
* @param tqparent MyMoneyAccount reference to new tqparent account
* @param sendNotification if true, notifications with the ids
* of all modified objects are send
*/
- void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& tqparent, const bool sendNotification);
+ void reparentAccount(MyMoneyAccount &account, MyMoneyAccount& parent, const bool sendNotification);
/**
* This method will close a database and log the use roff
*/
@@ -219,13 +219,13 @@ public:
* accordingly.
*
- * @param tqparent tqparent account the account should be added to
+ * @param parent parent account the account should be added to
* @param account the account to be added
*/
@@ -291,9 +291,9 @@ public:
*
* @param account MyMoneyAccount reference to account to be re-parented
- * @param tqparent MyMoneyAccount reference to new tqparent account
+ * @param parent MyMoneyAccount reference to new parent account
*/
@@ -1212,11 +1212,11 @@ private:
*
* @param account MyMoneyAccount reference to account to be re-parented
- * @param tqparent MyMoneyAccount reference to new tqparent account
+ * @param parent MyMoneyAccount reference to new parent account
* @param sendNotification if true, notifications with the ids
* of all modified objects are send